@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 # This Python file uses the following encoding: utf-8
 
-VERSION = (0,5,0)
+VERSION = (0,5,1)
 APPLICATION_NAME = "Dynamic Link"
 VERSION_str = str(VERSION).strip('()').replace(',','.').replace(' ','')
 VERSION_INFO = """
@@ -12,6 +12,9 @@ Modification date: 03.08.2011
 Hints:
 
 
+- 0.5.1     new stable
+- 0.5.0.2   some text in templates changed
+- 0.5.0.1   correct readme and example settings.py
 - 0.5.0     some changes - stable release
 - 0.4.9.4   install_requires in setup.py modified
 - 0.4.9.3   old data removed
